function [co] = IGV_initialization(mult)
%Initialization of the GV (generalized variance) estimator. 
%
%Note: 
%   1)The estimator is treated as a cost object (co).
%	2)We make use of the naming convention 'I<name>_initialization', to ease embedding new mutual information estimation methods.
%	3)For GV, the corresponding 'IGV_estimation.m' procedure has not been implemented, since GV is used in case of cost_type = 'Ipairwise1d', where the similarity matrix can be computed more
%	efficiently for GV (see 'I_similarity_matrix.m').
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: object (structure).
%REFERENCE: 
%   Zoltan Szabo, Andras Lorincz: Real and Complex Independent Subspace Analysis by Generalized Variance. ICARN-2006, pages 85-88.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'GV';
    co.mult = mult;
    
%other fields:
    %xor:
        co.dependency = 'corr';%use nonlinear correlations instead of nonlinear covariances.
        %co.dependency = 'cov';%use nonlinear covariances instead of nonlinear correlations.
