function [I] = IMMD_DMMD_estimation(Y,ds,co)
%Estimates mutual information (I) using the MMD (maximum mean discrepancy)
%method: I(Y_1,...,Y_d) = MMD(P_Z,P_U), where (i) Z =[F_1(Y_1);...;F_d(Y_d)] is the copula transformation of Y; F_i is the cdf of Y_i, (ii) P_U is the uniform distribution on [0,1]^d, (iii) dim(Y_1) = ... = dim(Y_d) = 1.
%This is a "meta" method, i.e., the MMD estimator can be arbitrary.
%
%INPUT:
%   Y: Y(:,t) is the t^th sample.
%  ds: subspace dimensions.
%  co: initialized mutual information estimator object.
%REFERENCE:
%  Barnabas Poczos, Zoubin Ghahramani, Jeff Schneider. Copula-based Kernel Dependency Measures, ICML-2012.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

if one_dimensional_problem(ds)
    Z = copula_transformation(Y);
    U = rand(size(Z));
    I = D_estimation(Z,U,co.member_co);
else
    disp('Error: the subspaces must be one-dimensional for this estimator.');
end
